infomaniak
    * ``auth_token`` Specify the token


.. note::
   
   Infomaniak Provider requires a token with domain scope.
   It can be generated for your Infomaniak account on the following URL:
   https://manager.infomaniak.com/v3/infomaniak-api

